==> vsf-1.0.2.tar.gz: vsf/src/Controller/VoiceSearchFeatureController.php <==
<?php

namespace Drupal\vsf\Controller;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\HtmlCommand;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Extension\ModuleExtensionList;
use Drupal\Core\Render\RendererInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for Voice search feature routes.
 */
final class VoiceSearchFeatureController extends ControllerBase {

  /**
   * The renderer service.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * The module extension list service.
   *
   * @var \Drupal\Core\Extension\ModuleExtensionList
   */
  protected $moduleExtensionList;

  /**
   * The configuration service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs a VoiceSearchFeatureController object.
   *
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   The renderer service.
   * @param \Drupal\Core\Extension\ModuleExtensionList $module_extension_list
   *   The module extension list service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration service.
   */
  public function __construct(RendererInterface $renderer, ModuleExtensionList $module_extension_list, ConfigFactoryInterface $config_factory) {
    $this->renderer = $renderer;
    $this->moduleExtensionList = $module_extension_list;
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('renderer'),
      $container->get('extension.list.module'),
      $container->get('config.factory')
    );
  }

  /**
   * Builds the response.
   */
  public function build() {
    $config = $this->configFactory->get('vsf.settings');

    $variables = [
      'modulePath' => $this->getModulePath(),
    ];
    $rendered_template = [
      '#theme' => 'vsf',
      '#modulePath' => $variables['modulePath'],
      '#speak_now_text' => $config->get('speak_now_text'),
      '#listening_text' => $config->get('listening_text'),
      '#did_not_get_text' => $config->get('did_not_get_text'),
    ];
    $html = $this->renderer->renderPlain($rendered_template);
    $response = new AjaxResponse();
    $response->addCommand(new HtmlCommand('#voice_search_wrapper', $html));
    return $response;
  }

  /**
   * Get the module path.
   */
  private function getModulePath() {
    return $this->moduleExtensionList->getPath('vsf');
  }

  /**
   * Configuration for menu.
   */
  public function configPage() {
    return [
      '#markup' => $this->t('This is the configuration page.'),
    ];
  }

}

==> vsf-1.0.3.tar.gz: vsf/src/Controller/VoiceSearchFeatureController.php <==
<?php

namespace Drupal\vsf\Controller;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\HtmlCommand;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Extension\ModuleExtensionList;
use Drupal\Core\Render\RendererInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;

/**
 * Returns responses for Voice search feature routes.
 */
final class VoiceSearchFeatureController implements ContainerInjectionInterface {

  /**
   * The renderer service.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * The module extension list service.
   *
   * @var \Drupal\Core\Extension\ModuleExtensionList
   */
  protected $moduleExtensionList;

  /**
   * The configuration service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs a VoiceSearchFeatureController object.
   *
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   The renderer service.
   * @param \Drupal\Core\Extension\ModuleExtensionList $module_extension_list
   *   The module extension list service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration service.
   */
  public function __construct(RendererInterface $renderer, ModuleExtensionList $module_extension_list, ConfigFactoryInterface $config_factory) {
    $this->renderer = $renderer;
    $this->moduleExtensionList = $module_extension_list;
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('renderer'),
      $container->get('extension.list.module'),
      $container->get('config.factory')
    );
  }

  /**
   * Builds the response.
   */
  public function build() {
    $config = $this->configFactory->get('vsf.settings');

    $variables = [
      'modulePath' => $this->getModulePath(),
    ];
    $rendered_template = [
      '#theme' => 'vsf',
      '#modulePath' => $variables['modulePath'],
      '#speak_now_text' => $config->get('speak_now_text'),
      '#listening_text' => $config->get('listening_text'),
      '#did_not_get_text' => $config->get('did_not_get_text'),
    ];
    $html = $this->renderer->renderPlain($rendered_template);
    $response = new AjaxResponse();
    $response->addCommand(new HtmlCommand('#voice_search_wrapper', $html));
    return $response;
  }

  /**
   * Get the module path.
   */
  private function getModulePath() {
    return $this->moduleExtensionList->getPath('vsf');
  }

  /**
   * Configuration for menu.
   */
  public function configPage() {
    return [
      '#markup' => $this->t('This is the configuration page.'),
    ];
  }

}
